package cn.com.infosec.asn1.ess;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.DigestInfo;
import cn.com.infosec.asn1.x509.IssuerSerial;

public class OtherCertID extends ASN1Encodable {
   private ASN1Encodable otherCertHash;
   private IssuerSerial issuerSerial;

   public static OtherCertID getInstance(Object o) {
      if (o != null && !(o instanceof OtherCertID)) {
         if (o instanceof ASN1Sequence) {
            return new OtherCertID((ASN1Sequence)o);
         } else {
            throw new IllegalArgumentException("unknown object in 'OtherCertID' factory : " + o.getClass().getName() + ".");
         }
      } else {
         return (OtherCertID)o;
      }
   }

   public OtherCertID(ASN1Sequence seq) {
      if (seq.size() >= 1 && seq.size() <= 2) {
         if (seq.getObjectAt(0).getDERObject() instanceof ASN1OctetString) {
            this.otherCertHash = ASN1OctetString.getInstance(seq.getObjectAt(0));
         } else {
            this.otherCertHash = DigestInfo.getInstance(seq.getObjectAt(0));
         }

         if (seq.size() > 1) {
            this.issuerSerial = new IssuerSerial(ASN1Sequence.getInstance(seq.getObjectAt(1)));
         }

      } else {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      }
   }

   public OtherCertID(AlgorithmIdentifier algId, byte[] digest) {
      OtherCertID var10000 = this;
      super();
      DigestInfo var3;
      var3 = new DigestInfo.<init>(algId, digest);
      var10000.otherCertHash = var3;
   }

   public OtherCertID(AlgorithmIdentifier algId, byte[] digest, IssuerSerial issuerSerial) {
      OtherCertID var10000 = this;
      OtherCertID var10001 = this;
      super();
      DigestInfo var4;
      var4 = new DigestInfo.<init>(algId, digest);
      var10001.otherCertHash = var4;
      var10000.issuerSerial = issuerSerial;
   }

   public AlgorithmIdentifier getAlgorithmHash() {
      return this.otherCertHash.getDERObject() instanceof ASN1OctetString ? new AlgorithmIdentifier("1.3.14.3.2.26") : DigestInfo.getInstance(this.otherCertHash).getAlgorithmId();
   }

   public byte[] getCertHash() {
      return this.otherCertHash.getDERObject() instanceof ASN1OctetString ? ((ASN1OctetString)this.otherCertHash.getDERObject()).getOctets() : DigestInfo.getInstance(this.otherCertHash).getDigest();
   }

   public IssuerSerial getIssuerSerial() {
      return this.issuerSerial;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.otherCertHash);
      IssuerSerial var2;
      if ((var2 = this.issuerSerial) != null) {
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
